aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLuis Lozano <llozano@google.com>2013-06-07 05:31:15 +0000
committerLuis Lozano <llozano@google.com>2013-06-07 05:31:15 +0000
commit788bac1f76dd538a80100489c3ccc3661bf3dfb3 (patch)
treeef3aff804cb0a7adf1d27f99abef054ddc8f1691
parent918cab8cbc9f393438e2258d4e222b89a0d6471a (diff)
Fixed comments from code review
git-svn-id: https://gcc.gnu.org/svn/gcc/branches/google/gcc-4_7-mobile-vtable-verification@199786 138bc75d-0d04-0410-961f-82ee72b054a4
-rw-r--r--gcc/cp/vtable-class-hierarchy.c4
-rw-r--r--libgcc/vtv_end_preinit.c6
-rw-r--r--libgcc/vtv_start_preinit.c6
-rw-r--r--libstdc++-v3/libsupc++/vtv_init.cc2
-rw-r--r--libstdc++-v3/libsupc++/vtv_rts.cc8
-rw-r--r--libstdc++-v3/libsupc++/vtv_utils.h2
6 files changed, 14 insertions, 14 deletions
diff --git a/gcc/cp/vtable-class-hierarchy.c b/gcc/cp/vtable-class-hierarchy.c
index c4d04c8a30d..27600ac9626 100644
--- a/gcc/cp/vtable-class-hierarchy.c
+++ b/gcc/cp/vtable-class-hierarchy.c
@@ -280,7 +280,7 @@ init_functions (void)
gcc_assert (vlt_register_set_fndecl == NULL_TREE);
gcc_assert (vlt_register_pairs_fndecl == NULL_TREE);
- /* Build arg types for __vtv_register_set[Debug], and initialize
+ /* Build arg types for __vtv_register_set[_debug], and initialize
vlt_register_set_fndecl. */
/* Arg1: Set handle ptr. */
@@ -326,7 +326,7 @@ init_functions (void)
retrofit_lang_decl (vlt_register_set_fndecl);
SET_DECL_LANGUAGE (vlt_register_set_fndecl, lang_cplusplus);
- /* Build arg types for __vtv_register_pair[Debug], and initialize
+ /* Build arg types for __vtv_register_pair[_debug], and initialize
vlt_register_set_fndecl. */
/* Arg1: Set handle ptr. */
diff --git a/libstdc++-v3/libsupc++/vtv_init.cc b/libstdc++-v3/libsupc++/vtv_init.cc
index f8bcc15c882..35d4bcf4c15 100644
--- a/libstdc++-v3/libsupc++/vtv_init.cc
+++ b/libstdc++-v3/libsupc++/vtv_init.cc
@@ -25,7 +25,7 @@
/* This file contains all the definitions that go into the libvtv_init
library, which is part of the vtable verification feature. This
- library should contain exactly two functionsa (__vtv_unprotect and
+ library should contain exactly two functions (__vtv_unprotect and
__vtv_protect) and one global variable definition
(__vtv_defined_in_vtv_init_lib). Any program that was compiled
with the option "-fvtable-verify=std" MUST also be linked with
diff --git a/libstdc++-v3/libsupc++/vtv_rts.cc b/libstdc++-v3/libsupc++/vtv_rts.cc
index 63793a50beb..c5f9e50c9ba 100644
--- a/libstdc++-v3/libsupc++/vtv_rts.cc
+++ b/libstdc++-v3/libsupc++/vtv_rts.cc
@@ -126,8 +126,8 @@
"-fvtable-verify=std" must be linked with libvtv_init.so (the gcc
driver has been modified to do this). vtv_stubs.so is built from
vtv_stubs.cc. It replaces the main runtime functions
- (__VLTChangePermissino, __vtv_register_pair and
- __VLTVerifyVtablePoitner) with stub functions that do nothing. If
+ (__vtv_change_permissions, __vtv_register_pair and
+ __vtv_verify_vtable_pointer) with stub functions that do nothing. If
a programmer has a library that was built with verification, but
wishes to not have verification turned on, the programmer can link
in the vtv_stubs.so library. */
@@ -811,9 +811,9 @@ __vtv_change_permission (int perm)
if (debug_functions)
{
if (perm == __VLTP_READ_WRITE)
- fprintf (stdout, "Changing VLT permisisons to Read-Write.\n");
+ fprintf (stdout, "Changing vtv_permisisons to Read-Write.\n");
else if (perm == __VLTP_READ_ONLY)
- fprintf (stdout, "Changing VLT permissions to Read-only.\n");
+ fprintf (stdout, "Changing vtv_permissions to Read-only.\n");
else
fprintf (stdout, "Unrecognized permissions value: %d\n", perm);
}
diff --git a/libstdc++-v3/libsupc++/vtv_utils.h b/libstdc++-v3/libsupc++/vtv_utils.h
index 6497abd71f0..98aeebaeac7 100644
--- a/libstdc++-v3/libsupc++/vtv_utils.h
+++ b/libstdc++-v3/libsupc++/vtv_utils.h
@@ -68,7 +68,7 @@ static inline unsigned long long
rdtsc ()
{
/* Create an empty function for unknown architectures, so that the
- calls to this function in vtv_malloc.c and vtv_rts.c do not cause
+ calls to this function in vtv_malloc.cc and vtv_rts.cc do not cause
compilation errors. */
return ((unsigned long long) 0);
}
diff --git a/libgcc/vtv_end_preinit.c b/libgcc/vtv_end_preinit.c
index 738f1339d53..d37bf806bc1 100644
--- a/libgcc/vtv_end_preinit.c
+++ b/libgcc/vtv_end_preinit.c
@@ -49,7 +49,7 @@ along with GCC; see the file COPYING3. If not see
#include "vtv-change-permission.h"
void
-__VLTProtectPreinit (void)
+__vlt_protect_preinit (void)
{
__vtv_change_permission (__VLTP_READ_ONLY);
}
@@ -59,8 +59,8 @@ char _vtable_map_vars_end[VTV_PAGE_SIZE]
__attribute__ ((__visibility__ ("protected"), used,
section(".vtable_map_vars")));
/* Put the function __VLTProtectPreinit into the .preinit_array
section. */
__attribute__ ((section (".preinit_array")))
- typeof (__VLTProtectPreinit) *__preinit_end = __VLTProtectPreinit;
+ typeof (__vlt_protect_preinit) *__preinit_end = __vlt_protect_preinit;
@@ -59,8 +59,8 @@ char _vtable_map_vars_end[VTV_PAGE_SIZE]
__attribute__ ((__visibility__ ("protected"), used,
section(".vtable_map_vars")));
-/* Put the function __VLTProtectPreinit into the .preinit_array
+/* Put the function __vlt_protect_preinit into the .preinit_array
section. */
__attribute__ ((section (".preinit_array")))
diff --git a/libgcc/vtv_start_preinit.c b/libgcc/vtv_start_preinit.c
index 3845f8ff17a..460db0fa7cb 100644
--- a/libgcc/vtv_start_preinit.c
+++ b/libgcc/vtv_start_preinit.c
@@ -48,7 +48,7 @@ along with GCC; see the file COPYING3. If not see
#include "vtv-change-permission.h"
void
-__VLTUnprotectPreinit (void)
+__vlt_unprotect_preinit (void)
{
__vtv_change_permission (__VLTP_READ_WRITE);
}
@@ -60,8 +60,8 @@ __attribute__ ((__visibility__ ("protected"), used, aligned(VTV_PAGE_SIZE),
= { };
/* Put the function __VLTUnprotectPreinit into the .preinit_array
section. */
__attribute__ ((section (".preinit_array")))
- typeof (__VLTUnprotectPreinit) *__preinit = __VLTUnprotectPreinit;
+ typeof (__vlt_unprotect_preinit) *__preinit = __vlt_unprotect_preinit;
@@ -60,8 +60,8 @@ __attribute__ ((__visibility__ ("protected"), used, aligned(VTV_PAGE_SIZE),
= { };
-/* Put the function __VLTUnprotectPreinit into the .preinit_array
+/* Put the function __vlt_unprotect_preinit into the .preinit_array
section. */
__attribute__ ((section (".preinit_array")))